# Geometry Box

A simple python package for geometrical operations.


+ Shape2D(Shape)
  + StraightLine
  + EllipticalArc
  + ClosedShape2D
    + Ellipse
    + Circle
    + RegularPolygon
    + Rectangle
    + CShape
    + NLobeShape
    + BoundingBox2D
    + BoundingBox

For each enclosed shape

+ Have locus `x` and `y`
+ Area `a`
+ Perimeter `p`
+ 
